==> ant-design-vue-4.0.6.jar: META-INF/resources/webjars/ant-design-vue/4.0.6/es/vc-picker/panels/TimePanel/TimeBody.d.ts <==
import type { GenerateConfig } from '../../generate';
import type { Locale, OnSelect } from '../../interface';
import type { SharedTimeProps } from '.';
import type { Ref } from 'vue';
export type BodyOperationRef = {
    onUpDown: (diff: number) => void;
};
export type TimeBodyProps<DateType> = {
    prefixCls: string;
    locale: Locale;
    generateConfig: GenerateConfig<DateType>;
    value?: DateType | null;
    onSelect: OnSelect<DateType>;
    activeColumnIndex: number;
    operationRef: Ref<BodyOperationRef | undefined>;
} & SharedTimeProps<DateType>;
declare const TimeBody: import("vue").DefineComponent<Readonly<{
    value?: any;
    onSelect?: any;
    prefixCls?: any;
    generateConfig?: any;
    operationRef?: any;
    hideDisabledOptions?: any;
    activeColumnIndex?: any;
    showHour?: any;
    showMinute?: any;
    showSecond?: any;
    use12Hours?: any;
    hourStep?: any;
    minuteStep?: any;
    secondStep?: any;
    disabledHours?: any;
    disabledMinutes?: any;
    disabledSeconds?: any;
    disabledTime?: any;
}>, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<Readonly<{
    value?: any;
    onSelect?: any;
    prefixCls?: any;
    generateConfig?: any;
    operationRef?: any;
    hideDisabledOptions?: any;
    activeColumnIndex?: any;
    showHour?: any;
    showMinute?: any;
    showSecond?: any;
    use12Hours?: any;
    hourStep?: any;
    minuteStep?: any;
    secondStep?: any;
    disabledHours?: any;
    disabledMinutes?: any;
    disabledSeconds?: any;
    disabledTime?: any;
}>>>, {
    readonly value?: any;
    readonly onSelect?: any;
    readonly prefixCls?: any;
    readonly generateConfig?: any;
    readonly operationRef?: any;
    readonly hideDisabledOptions?: any;
    readonly activeColumnIndex?: any;
    readonly showHour?: any;
    readonly showMinute?: any;
    readonly showSecond?: any;
    readonly use12Hours?: any;
    readonly hourStep?: any;
    readonly minuteStep?: any;
    readonly secondStep?: any;
    readonly disabledHours?: any;
    readonly disabledMinutes?: any;
    readonly disabledSeconds?: any;
    readonly disabledTime?: any;
}, {}>;
export default TimeBody;

==> ant-design-vue-4.1.1.jar: META-INF/resources/webjars/ant-design-vue/4.1.1/es/vc-picker/panels/TimePanel/TimeBody.d.ts <==
import type { GenerateConfig } from '../../generate';
import type { Locale, OnSelect } from '../../interface';
import type { SharedTimeProps } from '.';
import type { Ref } from 'vue';
export type BodyOperationRef = {
    onUpDown: (diff: number) => void;
};
export type TimeBodyProps<DateType> = {
    prefixCls: string;
    locale: Locale;
    generateConfig: GenerateConfig<DateType>;
    value?: DateType | null;
    onSelect: OnSelect<DateType>;
    activeColumnIndex: number;
    operationRef: Ref<BodyOperationRef | undefined>;
} & SharedTimeProps<DateType>;
declare const TimeBody: import("vue").DefineComponent<Readonly<{
    value?: any;
    onSelect?: any;
    prefixCls?: any;
    generateConfig?: any;
    operationRef?: any;
    hideDisabledOptions?: any;
    activeColumnIndex?: any;
    showHour?: any;
    showMinute?: any;
    showSecond?: any;
    use12Hours?: any;
    hourStep?: any;
    minuteStep?: any;
    secondStep?: any;
    disabledHours?: any;
    disabledMinutes?: any;
    disabledSeconds?: any;
    disabledTime?: any;
}>, () => import("vue/jsx-runtime").JSX.Element, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<Readonly<{
    value?: any;
    onSelect?: any;
    prefixCls?: any;
    generateConfig?: any;
    operationRef?: any;
    hideDisabledOptions?: any;
    activeColumnIndex?: any;
    showHour?: any;
    showMinute?: any;
    showSecond?: any;
    use12Hours?: any;
    hourStep?: any;
    minuteStep?: any;
    secondStep?: any;
    disabledHours?: any;
    disabledMinutes?: any;
    disabledSeconds?: any;
    disabledTime?: any;
}>>>, {
    readonly value?: any;
    readonly onSelect?: any;
    readonly prefixCls?: any;
    readonly generateConfig?: any;
    readonly operationRef?: any;
    readonly hideDisabledOptions?: any;
    readonly activeColumnIndex?: any;
    readonly showHour?: any;
    readonly showMinute?: any;
    readonly showSecond?: any;
    readonly use12Hours?: any;
    readonly hourStep?: any;
    readonly minuteStep?: any;
    readonly secondStep?: any;
    readonly disabledHours?: any;
    readonly disabledMinutes?: any;
    readonly disabledSeconds?: any;
    readonly disabledTime?: any;
}, {}>;
export default TimeBody;
